@@ -141,7 +141,7 @@ def _match_ips(text):
 class SimilarityLabelGenerator:
     def __init__(self, filename: str, platform='linux'):
         self._platform = platform
-        lines = open(filename).readlines()
+        lines = open(filename, encoding='utf-8').readlines()
         self._strings = []
         for s in lines:
             # s = s[:min(150, len(s))]
